@@ -1,8 +1,8 @@
 //===========================================================================
 //
-//	testcx2.cxx
+//      testcx2.cxx
 //
-//	uITRON "C++" test program two
+//      uITRON "C++" test program two
 //
 //===========================================================================
 //####COPYRIGHTBEGIN####
@@ -22,18 +22,18 @@
 // September 30, 1998.
 // 
 // The Initial Developer of the Original Code is Cygnus.  Portions created
-// by Cygnus are Copyright (C) 1998 Cygnus Solutions.  All Rights Reserved.
+// by Cygnus are Copyright (C) 1998,1999 Cygnus Solutions.  All Rights Reserved.
 // -------------------------------------------
 //
 //####COPYRIGHTEND####
 //===========================================================================
 //#####DESCRIPTIONBEGIN####
 //
-// Author(s): 	hmt
-// Contributors:	hmt
-// Date:	1998-03-13
-// Purpose:	uITRON API testing
-// Description:	
+// Author(s):   hmt
+// Contributors:        hmt
+// Date:        1998-03-13
+// Purpose:     uITRON API testing
+// Description: 
 //
 //####DESCRIPTIONEND####
 //
@@ -144,6 +144,10 @@ void task1( unsigned int arg )
     VP blfptr = (VP)foo;
     VP blkptr = (VP)foo;
 
+    int delay = 10;
+    if (cyg_test_is_simulator)
+        delay = 3;
+
     CYG_TEST_INFO( "Task 1 running" );
     ercd = get_tid( &scratch );
     CYG_TEST_CHECK( E_OK == ercd, "get_tid bad ercd" );
@@ -153,7 +157,7 @@ void task1( unsigned int arg )
     intercom = 1;
     ercd = sta_tsk( 2, 222 );
     CYG_TEST_CHECK( E_OK == ercd, "sta_tsk bad ercd" );
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
 
     // Semaphores; all the illegal argument combinations first
@@ -171,9 +175,9 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_ID == ercd, "preq_sem bad ercd !E_ID" );
     ercd = preq_sem( 99 );
     CYG_TEST_CHECK( E_ID == ercd, "preq_sem bad ercd !E_ID" );
-    ercd = twai_sem( -6, 10 );
+    ercd = twai_sem( -6, delay );
     CYG_TEST_CHECK( E_ID == ercd, "twai_sem bad ercd !E_ID" );
-    ercd = twai_sem( 99, 10 );
+    ercd = twai_sem( 99, delay );
     CYG_TEST_CHECK( E_ID == ercd, "twai_sem bad ercd !E_ID" );
     ercd = twai_sem( 2, -999 );
     CYG_TEST_CHECK( E_PAR == ercd, "twai_sem bad ercd !E_PAR" );
@@ -191,7 +195,7 @@ void task1( unsigned int arg )
     // check the waitable functions versus dispatch disable
     ercd = preq_sem( 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "preq_sem bad ercd !E_TMOUT" );
-    ercd = twai_sem( 2, 10 );
+    ercd = twai_sem( 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_sem bad ercd !E_TMOUT" );
     ercd = twai_sem( 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_sem(POL) bad ercd !E_TMOUT" );
@@ -200,7 +204,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = wai_sem( 2 );
     CYG_TEST_CHECK( E_CTX == ercd, "wai_sem bad ercd !E_CTX" );
-    ercd = twai_sem( 2, 10 );
+    ercd = twai_sem( 2, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "twai_sem bad ercd !E_CTX" );
     ercd = twai_sem( 2, TMO_FEVR );
     CYG_TEST_CHECK( E_CTX == ercd, "twai_sem(FEVR) bad ercd !E_CTX" );
@@ -213,7 +217,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ena_dsp bad ercd" );
     ercd = preq_sem( 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "preq_sem bad ercd !E_TMOUT" );
-    ercd = twai_sem( 2, 10 );
+    ercd = twai_sem( 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_sem bad ercd !E_TMOUT" );
     ercd = twai_sem( 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_sem(POL) bad ercd !E_TMOUT" );
@@ -254,14 +258,14 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ref_sem bad ercd" );
     CYG_TEST_CHECK( 0 == sem_info.wtsk, "sem.wtsk should be 0" );
     CYG_TEST_CHECK( 1 == sem_info.semcnt, "semcnt should be 1" );
-    ercd = twai_sem( 2, 10 );
+    ercd = twai_sem( 2, delay );
     CYG_TEST_CHECK( E_OK == ercd, "wai_sem bad ercd" );
     ercd = ref_sem( &sem_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_sem bad ercd" );
     CYG_TEST_CHECK( 0 == sem_info.wtsk, "sem.wtsk should be 0" );
     CYG_TEST_CHECK( 0 == sem_info.semcnt, "semcnt should be 0" );
     intercom = 0;
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     intercom = 1;
     ercd = ref_sem( &sem_info, 2 );
@@ -278,7 +282,7 @@ void task1( unsigned int arg )
 #else // old, non-uITRON semantics
     CYG_TEST_CHECK( 1 == sem_info.semcnt, "semcnt should be 1" );
 #endif
-    ercd = dly_tsk( 10 );               // let task 2 pick up the signal
+    ercd = dly_tsk( delay );               // let task 2 pick up the signal
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_sem( &sem_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_sem bad ercd" );
@@ -321,19 +325,19 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_PAR == ercd, "pol_flg bad ercd !E_PAR" );
     ercd = pol_flg( &flagptn, 2, 0, TWF_ANDW );
     CYG_TEST_CHECK( E_PAR == ercd, "pol_flg bad ercd !E_PAR" );
-    ercd = twai_flg( &flagptn, -6, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, -6, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_ID == ercd, "twai_flg bad ercd !E_ID" );
-    ercd = twai_flg( &flagptn, 99, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, 99, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_ID == ercd, "twai_flg bad ercd !E_ID" );
 #ifndef CYGSEM_UITRON_PARAMS_NULL_IS_GOOD_PTR
-    ercd = twai_flg( NULL, 2, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( NULL, 2, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "twai_flg bad ercd !E_PAR" );
 #endif
-    ercd = twai_flg( &flagptn, 2, 7, 34657, 10 );
+    ercd = twai_flg( &flagptn, 2, 7, 34657, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "twai_flg bad ercd !E_PAR" );
     ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, -999 );
     CYG_TEST_CHECK( E_PAR == ercd, "twai_flg bad ercd !E_PAR" );
-    ercd = twai_flg( &flagptn, 2, 0, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, 2, 0, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "twai_flg bad ercd !E_PAR" );
     ercd = ref_flg( &flg_info, -6 );
     CYG_TEST_CHECK( E_ID == ercd, "ref_flg bad ercd !E_ID" );
@@ -349,7 +353,7 @@ void task1( unsigned int arg )
     // check the waitable functions versus dispatch disable
     ercd = pol_flg( &flagptn, 2, 7, TWF_ANDW );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pol_flg bad ercd !E_TMOUT" );
-    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_flg bad ercd !E_TMOUT" );
     ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_flg(POL) bad ercd !E_TMOUT" );
@@ -358,7 +362,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = wai_flg( &flagptn, 2, 7, TWF_ANDW );
     CYG_TEST_CHECK( E_CTX == ercd, "wai_flg bad ercd !E_CTX" );
-    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "twai_flg bad ercd !E_CTX" );
     ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, TMO_FEVR );
     CYG_TEST_CHECK( E_CTX == ercd, "twai_flg(FEVR) bad ercd !E_CTX" );
@@ -371,7 +375,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ena_dsp bad ercd" );
     ercd = pol_flg( &flagptn, 2, 7, TWF_ANDW );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pol_flg bad ercd !E_TMOUT" );
-    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, 10 );
+    ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_flg bad ercd !E_TMOUT" );
     ercd = twai_flg( &flagptn, 2, 7, TWF_ANDW, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "twai_flg(POL) bad ercd !E_TMOUT" );
@@ -383,7 +387,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0 == flg_info.wtsk, "flg.wtsk should be non0" );
     CYG_TEST_CHECK( 0 == flg_info.flgptn, "flgptn should be 0" );
     intercom = 0;
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     intercom = 1;
     ercd = ref_flg( &flg_info, 2 );
@@ -392,7 +396,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0 == flg_info.flgptn, "flgptn should be 0" );
     ercd = set_flg( 2, 0x5555 );
     CYG_TEST_CHECK( E_OK == ercd, "sig_flg bad ercd" );
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_flg( &flg_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_flg bad ercd" );
@@ -400,7 +404,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0x5555 == flg_info.flgptn, "flgptn should be 0x5555" );
     ercd = clr_flg( 2, 0xF0F0 );
     CYG_TEST_CHECK( E_OK == ercd, "clr_flg bad ercd" );
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_flg( &flg_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_flg bad ercd" );
@@ -408,7 +412,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0x5050 == flg_info.flgptn, "flgptn should be 0x5050" );
     ercd = set_flg( 2, 0xFFFF );
     CYG_TEST_CHECK( E_OK == ercd, "sig_flg bad ercd" );
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_flg( &flg_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_flg bad ercd" );
@@ -443,14 +447,14 @@ void task1( unsigned int arg )
     ercd = prcv_msg( NULL, 2 );
     CYG_TEST_CHECK( E_PAR == ercd, "prcv_msg bad ercd !E_PAR" );
 #endif
-    ercd = trcv_msg( &rxptr, -6, 10 );
+    ercd = trcv_msg( &rxptr, -6, delay );
     CYG_TEST_CHECK( E_ID == ercd, "trcv_msg bad ercd !E_ID" );
-    ercd = trcv_msg( &rxptr, 99, 10 );
+    ercd = trcv_msg( &rxptr, 99, delay );
     CYG_TEST_CHECK( E_ID == ercd, "trcv_msg bad ercd !E_ID" );
     ercd = trcv_msg( &rxptr, 2, -999 );
     CYG_TEST_CHECK( E_PAR == ercd, "trcv_msg bad ercd !E_PAR" );
 #ifndef CYGSEM_UITRON_PARAMS_NULL_IS_GOOD_PTR
-    ercd = trcv_msg( NULL, 2, 10 );
+    ercd = trcv_msg( NULL, 2, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "trcv_msg bad ercd !E_PAR" );
 #endif
     ercd = ref_mbx( &mbx_info, -6 );
@@ -467,7 +471,7 @@ void task1( unsigned int arg )
     // check the waitable functions versus dispatch disable
     ercd = prcv_msg( &rxptr, 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "prcv_msg bad ercd !E_TMOUT" );
-    ercd = trcv_msg( &rxptr, 2, 10 );
+    ercd = trcv_msg( &rxptr, 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "trcv_msg bad ercd !E_TMOUT" );
     ercd = trcv_msg( &rxptr, 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "trcv_msg(POL) bad ercd !E_TMOUT" );
@@ -476,7 +480,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = rcv_msg( &rxptr, 2 );
     CYG_TEST_CHECK( E_CTX == ercd, "rcv_msg bad ercd !E_CTX" );
-    ercd = trcv_msg( &rxptr, 2, 10 );
+    ercd = trcv_msg( &rxptr, 2, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "trcv_msg bad ercd !E_CTX" );
     ercd = trcv_msg( &rxptr, 2, TMO_FEVR );
     CYG_TEST_CHECK( E_CTX == ercd, "trcv_msg(FEVR) bad ercd !E_CTX" );
@@ -489,7 +493,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ena_dsp bad ercd" );
     ercd = prcv_msg( &rxptr, 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "prcv_msg bad ercd !E_TMOUT" );
-    ercd = trcv_msg( &rxptr, 2, 10 );
+    ercd = trcv_msg( &rxptr, 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "trcv_msg bad ercd !E_TMOUT" );
     ercd = trcv_msg( &rxptr, 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "trcv_msg(POL) bad ercd !E_TMOUT" );
@@ -501,7 +505,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0 == mbx_info.wtsk, "mbx.wtsk should be 0" );
     CYG_TEST_CHECK( NADR == mbx_info.pk_msg, "mbx peek should be NADR" );
     intercom = 0;
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     intercom = 1;
     ercd = ref_mbx( &mbx_info, 2 );
@@ -518,7 +522,7 @@ void task1( unsigned int arg )
 #else // old, non-uITRON semantics
     CYG_TEST_CHECK( msgptr == mbx_info.pk_msg, "mbx peek should be msgptr" );
 #endif
-    ercd = dly_tsk( 10 );
+    ercd = dly_tsk( delay );
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_mbx( &mbx_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_mbx bad ercd" );
@@ -572,14 +576,14 @@ void task1( unsigned int arg )
     ercd = pget_blf( NULL, 2 );
     CYG_TEST_CHECK( E_PAR == ercd, "pget_blf bad ercd !E_PAR" );
 #endif
-    ercd = tget_blf( &blfptr, -6, 10 );
+    ercd = tget_blf( &blfptr, -6, delay );
     CYG_TEST_CHECK( E_ID == ercd, "tget_blf bad ercd !E_ID" );
-    ercd = tget_blf( &blfptr, 99, 10 );
+    ercd = tget_blf( &blfptr, 99, delay );
     CYG_TEST_CHECK( E_ID == ercd, "tget_blf bad ercd !E_ID" );
     ercd = tget_blf( &blfptr, 2, -999 );
     CYG_TEST_CHECK( E_PAR == ercd, "tget_blf bad ercd !E_PAR" );
 #ifndef CYGSEM_UITRON_PARAMS_NULL_IS_GOOD_PTR
-    ercd = tget_blf( NULL, 2, 10 );
+    ercd = tget_blf( NULL, 2, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "tget_blf bad ercd !E_PAR" );
 #endif
     ercd = ref_mpf( &mpf_info, -6 );
@@ -598,7 +602,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "pget_blf bad ercd" );
     ercd = rel_blf( 2, blfptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blf bad ercd" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_OK == ercd, "tget_blf bad ercd" );
     ercd = dis_dsp();
     CYG_TEST_CHECK( E_OK == ercd, "dis_dsp bad ercd" );
@@ -607,7 +611,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = get_blf( &blfptr, 2 );
     CYG_TEST_CHECK( E_CTX == ercd, "get_blf bad ercd !E_CTX" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blf bad ercd !E_CTX" );
 #endif // we can test bad param error returns
     ercd = ena_dsp();
@@ -616,7 +620,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "pget_blf bad ercd" );
     ercd = rel_blf( 2, blfptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blf bad ercd" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_OK == ercd, "tget_blf bad ercd" );
     ercd = rel_blf( 2, blfptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blf bad ercd" );
@@ -626,7 +630,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blf bad ercd !E_TMOUT" );
     ercd = pget_blf( &blfptr, 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blf bad ercd !E_TMOUT" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blf bad ercd !E_TMOUT" );
     ercd = tget_blf( &blfptr, 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blf(POL) bad ercd !E_TMOUT" );
@@ -635,7 +639,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = get_blf( &blfptr, 2 );
     CYG_TEST_CHECK( E_CTX == ercd, "get_blf bad ercd !E_CTX" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blf bad ercd !E_CTX" );
     ercd = tget_blf( &blfptr, 2, TMO_FEVR );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blf(FEVR) bad ercd !E_CTX" );
@@ -646,7 +650,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ena_dsp bad ercd" );
     ercd = pget_blf( &blfptr, 2 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blf bad ercd !E_TMOUT" );
-    ercd = tget_blf( &blfptr, 2, 10 );
+    ercd = tget_blf( &blfptr, 2, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blf bad ercd !E_TMOUT" );
     ercd = tget_blf( &blfptr, 2, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blf(POL) bad ercd !E_TMOUT" );
@@ -658,7 +662,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( 0 == mpf_info.wtsk, "mpf.wtsk should be 0" );
     CYG_TEST_CHECK( 0 == mpf_info.frbcnt, "mpf.frbcnt should be 0" );
     intercom = 0;
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     intercom = 1;
     ercd = ref_mpf( &mpf_info, 2 );
@@ -675,7 +679,7 @@ void task1( unsigned int arg )
 #else // old, non-uITRON semantics
     CYG_TEST_CHECK( 0 != mpf_info.frbcnt, "mpf.frbcnt should be non0" );
 #endif
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_mpf( &mpf_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_mpf bad ercd" );
@@ -714,14 +718,14 @@ void task1( unsigned int arg )
     ercd = pget_blk( NULL, 2, 100 );
     CYG_TEST_CHECK( E_PAR == ercd, "pget_blk bad ercd !E_PAR" );
 #endif
-    ercd = tget_blk( &blkptr, -6, 100, 10 );
+    ercd = tget_blk( &blkptr, -6, 100, delay );
     CYG_TEST_CHECK( E_ID == ercd, "tget_blk bad ercd !E_ID" );
-    ercd = tget_blk( &blkptr, 99, 100, 10 );
+    ercd = tget_blk( &blkptr, 99, 100, delay );
     CYG_TEST_CHECK( E_ID == ercd, "tget_blk bad ercd !E_ID" );
     ercd = tget_blk( &blkptr, 2, 100, -999 );
     CYG_TEST_CHECK( E_PAR == ercd, "tget_blk bad ercd !E_PAR" );
 #ifndef CYGSEM_UITRON_PARAMS_NULL_IS_GOOD_PTR
-    ercd = tget_blk( NULL, 2, 100, 10 );
+    ercd = tget_blk( NULL, 2, 100, delay );
     CYG_TEST_CHECK( E_PAR == ercd, "tget_blk bad ercd !E_PAR" );
 #endif
     ercd = ref_mpl( &mpl_info, -6 );
@@ -740,7 +744,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "pget_blk bad ercd" );
     ercd = rel_blk( 2, blkptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blk bad ercd" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_OK == ercd, "tget_blk bad ercd" );
     ercd = dis_dsp();
     CYG_TEST_CHECK( E_OK == ercd, "dis_dsp bad ercd" );
@@ -749,7 +753,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = get_blk( &blkptr, 2, 100 );
     CYG_TEST_CHECK( E_CTX == ercd, "get_blk bad ercd !E_CTX" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blk bad ercd !E_CTX" );
 #endif // we can test bad param error returns
     ercd = ena_dsp();
@@ -758,7 +762,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "pget_blk bad ercd" );
     ercd = rel_blk( 2, blkptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blk bad ercd" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_OK == ercd, "tget_blk bad ercd" );
     ercd = rel_blk( 2, blkptr );
     CYG_TEST_CHECK( E_OK == ercd, "rel_blk bad ercd" );
@@ -768,7 +772,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blk bad ercd !E_TMOUT" );
     ercd = pget_blk( &blkptr, 2, 100 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blk bad ercd !E_TMOUT" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blk bad ercd !E_TMOUT" );
     ercd = tget_blk( &blkptr, 2, 100, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blk(POL) bad ercd !E_TMOUT" );
@@ -777,7 +781,7 @@ void task1( unsigned int arg )
 #ifdef CYGSEM_UITRON_BAD_PARAMS_RETURN_ERRORS
     ercd = get_blk( &blkptr, 2, 100 );
     CYG_TEST_CHECK( E_CTX == ercd, "get_blk bad ercd !E_CTX" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blk bad ercd !E_CTX" );
     ercd = tget_blk( &blkptr, 2, 100, TMO_FEVR );
     CYG_TEST_CHECK( E_CTX == ercd, "tget_blk(FEVR) bad ercd !E_CTX" );
@@ -788,7 +792,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( E_OK == ercd, "ena_dsp bad ercd" );
     ercd = pget_blk( &blkptr, 2, 100 );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blk bad ercd !E_TMOUT" );
-    ercd = tget_blk( &blkptr, 2, 100, 10 );
+    ercd = tget_blk( &blkptr, 2, 100, delay );
     CYG_TEST_CHECK( E_TMOUT == ercd, "pget_blk bad ercd !E_TMOUT" );
     ercd = tget_blk( &blkptr, 2, 100, TMO_POL );
     CYG_TEST_CHECK( E_TMOUT == ercd, "tget_blk(POL) bad ercd !E_TMOUT" );
@@ -801,7 +805,7 @@ void task1( unsigned int arg )
     CYG_TEST_CHECK( mpl_info.maxsz <= mpl_info.frsz,
                     "mpl.maxsz not < mpl.frsz" );
     intercom = 0;
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     intercom = 1;
     ercd = ref_mpl( &mpl_info, 2 );
@@ -812,7 +816,7 @@ void task1( unsigned int arg )
     ercd = ref_mpl( &mpl_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_mpl bad ercd" );
     CYG_TEST_CHECK( 0 == mpl_info.wtsk, "mpl.wtsk should be 0" );
-    ercd = dly_tsk( 10 );               // let task 2 start waiting
+    ercd = dly_tsk( delay );               // let task 2 start waiting
     CYG_TEST_CHECK( E_OK == ercd, "dly_tsk bad ercd" );
     ercd = ref_mpl( &mpl_info, 2 );
     CYG_TEST_CHECK( E_OK == ercd, "ref_mpl bad ercd" );
@@ -900,12 +904,12 @@ void task4( unsigned int arg )
 #else // ! CYGVAR_KERNEL_COUNTERS_CLOCK   - can't test without it
 #define N_A_MSG "no CYGVAR_KERNEL_COUNTERS_CLOCK "
 #endif // ! CYGVAR_KERNEL_COUNTERS_CLOCK  - can't test without it
-#else  // ! CYGFUN_KERNEL_THREADS_TIMER	  - can't test without it
+#else  // ! CYGFUN_KERNEL_THREADS_TIMER   - can't test without it
 #define N_A_MSG "no CYGFUN_KERNEL_THREADS_TIMER"
-#endif // ! CYGFUN_KERNEL_THREADS_TIMER	  - can't test without it
-#else  // ! CYGIMP_THREAD_PRIORITY	  - can't test without it
+#endif // ! CYGFUN_KERNEL_THREADS_TIMER   - can't test without it
+#else  // ! CYGIMP_THREAD_PRIORITY        - can't test without it
 #define N_A_MSG "no CYGSEM_KERNEL_SCHED_MLQUEUE"
-#endif // ! CYGSEM_KERNEL_SCHED_MLQUEUE	  - can't test without it
+#endif // ! CYGSEM_KERNEL_SCHED_MLQUEUE   - can't test without it
 #else  // ! CYGPKG_UITRON
 #define N_A_MSG "uITRON Compatibility layer disabled"
 #endif // CYGPKG_UITRON
@@ -915,8 +919,7 @@ externC void
 cyg_start( void )
 {
     CYG_TEST_INIT();
-    CYG_TEST_PASS( "N/A: " N_A_MSG );
-    CYG_TEST_EXIT( "N/A" );
+    CYG_TEST_NA( N_A_MSG );
 }
 #endif // N_A_MSG defined ie. we are N/A.
 
